@@ -15,6 +15,6 @@ func New() (cmd *cobra.Command) {
 	cmd = command.New("kubernetes", short, long, nil)
 	cmd.Aliases = []string{"k8s"}
 	cmd.AddCommand(create(), destroy(), list(), kubectlToken(), saveKubeconfig())
-	cmd.Hidden = true
+	cmd.Hidden = false
 	return cmd
 }
